package com.ibm.etools.iseries.examples.dfu.CustomerOrderInquiry;


// Licensed Material - Property of IBM
// (C) Copyright IBM Corp. 2002 - All Rights Reserved
//
// DISCLAIMER:
// The following [enclosed] code is sample code created by IBM
// Corporation.  This sample code is not part of any standard IBM product
// and is provided to you solely for the purpose of assisting you in the
// development of your applications.  The code is provided 'AS IS',
// without warranty of any kind.  IBM shall not be liable for any damages
// arising out of your use of the sample code, even if IBM has been
// advised of the possibility of such damages.

/**
 * This sample will refer to iSeries files in ADTSLAB library. To be able
 * to run the sample, you have to first restore ADTSLAB savf from library
 * QPDA in WebSphere Development Studio product on V5R1M0 or later releases.
 * For early releases, you need to apply the appropriate PTF listed below
 * for the Application Development ToolSet/400 product:
 *
 * iSeries Release		LPP Number		PTF Number
 * V4R2M0				5769PW100		SF63545
 * V4R4M0				5769PW100		SF63703
 *
 *
 * This sample program demonstrates the use of a FormManager with 
 * a ListManager.
 *
 * This sample program demonstrates how to retrieve each part
 * record from a database "PRODDTL" in library "ADTSLAB", then, 
 * based on the part number of the record retrieved, finds all of 
 * the customer order records from another database file "PARTORDER"
 * in library "ADTSLAB".
 * 
 * Functions that you can perform with the example:
 * 1) Click on button "Read Next". The next record from the top of the
 * file is displayed, and based on the PARTNO value of the retrieved
 * record, all the customer order records will be displayed in the 
 * table.
 * 
 */

import javax.swing.*;
import com.ibm.etools.iseries.ui.*;


public class CustomerOrderInquiry extends JFrame implements java.awt.event.ActionListener
{
	private JButton 		bReadNext	= null;
	private JTextField 		tModel 		= null;
	private JTextField 		tPartd 		= null;
	private JTextField 		tPartNo 	= null;
	private JTextField 		tInventory	= null;
	private JFormattedTable table = null;
	private com.ibm.as400.access.AS400 as400 = null;
	private com.ibm.etools.iseries.ui.FormManager formManager = null;
	private com.ibm.etools.iseries.ui.ListManager listManager = null;


/**
 * CustomerOrderInquiry constructor.
 */
public CustomerOrderInquiry() 
{
	super("Cutomer Order Inquiry");
	setDefaultCloseOperation(WindowConstants.DISPOSE_ON_CLOSE);
	setSize(543, 475);
	setContentPane(getJFrameContentPane());
	
}



public void actionPerformed(java.awt.event.ActionEvent e) 
{
	if (e.getSource() == bReadNext) 
	{
		String[] key = new String[1];
		try
		{
			//clear all the data in the table first
			getListManager().clearAllData();
			
			// populate the form with data from the next record of the
			// database that associates to the formManager.
			getFormManager().readNextRecord();
			
			// use Part No as the key to retrieve all the records 
			// from the database that associates to the listManager.
			key[0] = tPartNo.getText();		
			getListManager().readAllRecordsEqual(key);
		}
		catch (Exception ex)
		{
			ex.printStackTrace();
		}
	}
}


/**
 * Return the AS4001 property value.
 * @return com.ibm.as400.access.AS400
 */
private com.ibm.as400.access.AS400 getAS400() 
{
	if (as400 == null) 
	{
		try 
		{
			as400 = new com.ibm.as400.access.AS400();
		} 
		catch (java.lang.Throwable ex) 
		{
			ex.printStackTrace();
		}
	}
	return as400;
}
/**
 * Return the FormManager1 property value.
 * @return com.ibm.etools.iseries.ui.FormManager
 */
private com.ibm.etools.iseries.ui.FormManager getFormManager() 
{
	if (formManager == null) 
	{
		try 
		{
			formManager = new FormManager();
			formManager.setRecordIOManager(new RecordIOManager("PRODDTL","ADTSLAB"));
			formManager.setSystem(getAS400());
		} 
		catch (java.lang.Throwable ex) 
		{
			ex.printStackTrace();
		}
	}
	return formManager;
}
/**
 * Return the JFrameContentPane property value.
 * @return JPanel
 */
private JPanel getJFrameContentPane() 
{
		JPanel contentPane = new JPanel();
		contentPane.setLayout(null);
		
		JLabel label1 = new JLabel("Inventory Parts");
		label1.setBounds(14, 21, 121, 14);
		label1.setForeground(java.awt.Color.black);
		contentPane.add(label1);
			
		JLabel label2 = new JLabel("Part No.");
		label2.setBounds(14, 52, 121, 18);
		contentPane.add(label2);
			
		JLabel label3 = new JLabel("Model");
		label3.setBounds(14, 81, 121, 18);
		contentPane.add(label3);
			
		JLabel label4 = new JLabel("Inventory");
		label4.setBounds(14, 110, 121, 19);
		contentPane.add(label4);
			
		JLabel label5 = new JLabel("Description");
		label5.setBounds(14, 138, 121, 18);
		contentPane.add(label5);
			
		JLabel label6 = new JLabel("Customer Orders");
		label6.setBounds(14, 180, 121, 14);
		label6.setForeground(java.awt.Color.black);
		contentPane.add(label6);
		
		tPartNo = new JTextField();
		tPartNo.setName("PARTNO");
		tPartNo.setBounds(147, 52, 205, 18);
		contentPane.add(tPartNo);
			
		tModel = new JTextField();
		tModel.setName("model");
		tModel.setBounds(147, 81, 205, 18);
		contentPane.add(tModel);
		
		tPartd = new JTextField();
		tPartd.setName("partd");
		tPartd.setBounds(147, 138, 373, 18);
		contentPane.add(tPartd);
		
		tInventory = new JTextField();
		tInventory.setName("inventory");
		tInventory.setBounds(147, 110, 205, 19);
		contentPane.add(tInventory);
		
		JScrollPane scrollPane = new JScrollPane();
		scrollPane.setVerticalScrollBarPolicy(JScrollPane.VERTICAL_SCROLLBAR_ALWAYS);
		scrollPane.setHorizontalScrollBarPolicy(JScrollPane.HORIZONTAL_SCROLLBAR_ALWAYS);

		table = new JFormattedTable();
		table.setBounds(0, 0, 200, 200);
		scrollPane.setColumnHeaderView(table.getTableHeader());
		scrollPane.setBounds(16, 202, 508, 218);
		scrollPane.setViewportView(table);
		contentPane.add(scrollPane);
		
		bReadNext = new JButton("ReadNext");
		bReadNext.setBounds(397, 54, 100, 25);
		contentPane.add(bReadNext);

		bReadNext.addActionListener(this);
		
		getFormManager().setDisplayContainer(contentPane);
		getListManager().setDisplayContainer(table);
		
	return contentPane;
}


/**
 * Return the ListManager1 property value.
 * @return com.ibm.etools.iseries.ui.ListManager
 */
private com.ibm.etools.iseries.ui.ListManager getListManager() 
{
	if (listManager == null) 
	{
		try 
		{
			listManager = new ListManager();
			listManager.setRecordIOManager(new RecordIOManager("PARTORDER","ADTSLAB"));
			listManager.setSystem(getAS400());
			
		} 
		catch (java.lang.Throwable ex) 
		{
			ex.printStackTrace();
		}
	}
	return listManager;
}
/**
 * main entrypoint - starts the part when it is run as an application
 * @param args java.lang.String[]
 */
public static void main(java.lang.String[] args) {
	try {
		CustomerOrderInquiry aCustomerOrderInquiry;
		aCustomerOrderInquiry = new CustomerOrderInquiry();
		aCustomerOrderInquiry.addWindowListener(new java.awt.event.WindowAdapter() {
			public void windowClosing(java.awt.event.WindowEvent e) {
				System.exit(0);
			};
		});
		aCustomerOrderInquiry.show();
		aCustomerOrderInquiry.setVisible(true);
	} catch (Throwable exception) {
		System.err.println("Exception occurred in main() of JFrame");
		exception.printStackTrace(System.out);
	}
}
}
