package com.ibm.etools.iseries.examples.dfu.ListManagerJoinDatabases;


// Licensed Material - Property of IBM
// (C) Copyright IBM Corp. 2002 - All Rights Reserved
//
// DISCLAIMER:
// The following [enclosed] code is sample code created by IBM
// Corporation.  This sample code is not part of any standard IBM product
// and is provided to you solely for the purpose of assisting you in the
// development of your applications.  The code is provided 'AS IS',
// without warranty of any kind.  IBM shall not be liable for any damages
// arising out of your use of the sample code, even if IBM has been
// advised of the possibility of such damages.

/**
 * This sample will refer to iSeries files in ADTSLAB library. To be able
 * to run the sample, you have to first restore ADTSLAB savf from library
 * QPDA in WebSphere Development Studio product on V5R1M0 or later releases.
 * For early releases, you need to apply the appropriate PTF listed below
 * for the Application Development ToolSet/400 product:
 *
 * iSeries Release		LPP Number		PTF Number
 * V4R2M0				5769PW100		SF63545
 * V4R4M0				5769PW100		SF63703
 *
 *
 * This sample program demonstrates the use of ListManager.
 *
 * This sample program demonstrates how to join two database
 * files in a JTable using ListManager. Database PRODDTL is joined
 * to database MODEL by foreign keys MODEL and PARTSHIP.
 * 
 * Functions that you can perform with the example:
 * 1) When button "Read All" is pressed, only records that have equal values
 * in foreign keys MODEL and PARTSHIP are retrieved.
 * 
 * 2) When button "Close File" is pressed, all the database files are closed
 * and the table is cleared.
 * 
 */

import javax.swing.*;
import javax.swing.table.*;
import com.ibm.etools.iseries.ui.*;
import com.ibm.as400.access.*;


public class ListManagerJoinDatabases extends JFrame implements 
	java.awt.event.ActionListener, java.awt.event.WindowListener 
{
	private static final String key1 [] = {"MODEL", "PARTSHIP"};

	private JButton bReadAll = null;
	private JButton bCloseFile = null;
	private JTable table = null;
	private com.ibm.as400.access.AS400 as400 = null;
	private com.ibm.etools.iseries.ui.ListManager listManager1 = null;
	private com.ibm.etools.iseries.ui.ListManager listManager2 = null;
	
	


public void actionPerformed(java.awt.event.ActionEvent e) 
{
	Object obj = e.getSource();
	
	try
	{
		if (obj == bReadAll) 
			getListManager1().readAllRecords();
		else if (obj == bCloseFile) 
			getListManager1().closeFile();
	}
	catch (Exception ex)
	{
		ex.printStackTrace();
	}
}

public void windowActivated(java.awt.event.WindowEvent e) {};
public void windowClosed(java.awt.event.WindowEvent e) {};
public void windowClosing(java.awt.event.WindowEvent e) {};
public void windowDeactivated(java.awt.event.WindowEvent e) {};
public void windowDeiconified(java.awt.event.WindowEvent e) {};
public void windowIconified(java.awt.event.WindowEvent e) {};

public void windowOpened(java.awt.event.WindowEvent e) 
{
	if (e.getSource() == this) 
	{
		getListManager1().joinDataBase(key1, getListManager2());
	}

}
/**
 * Constructor comment.
 */
public ListManagerJoinDatabases() {
	super("ListManager Join Databases");
	setSize(697, 403);
	setContentPane(getJFrameContentPane());
	
}
/**
 * Return the JFrameContentPane property value.
 * @return JPanel
 */
private JPanel getJFrameContentPane() 
{
	JPanel contentPane = new JPanel();
	contentPane.setLayout(null);
	
	table = new JTable();
	JScrollPane scrollPane = new JScrollPane();
	table.setBounds(0, 0, 200, 200);
	table.setAutoCreateColumnsFromModel(false);

	// create table column 1
	TableColumn col1 = new TableColumn();
	col1.setIdentifier("PARTNO");
	col1.setHeaderValue("Part No.");
	table.addColumn(col1);
	
	// create table column 2
	TableColumn col2 = new TableColumn();
	col2.setIdentifier("INVENTORY");
	col2.setHeaderValue("Inventory");
	table.addColumn(col2);
	
	// create table column 3
	TableColumn col3 = new TableColumn();
	col3.setIdentifier("MODEL");
	col3.setHeaderValue("Model");
	table.addColumn(col3);
	
	// create table column 4
	TableColumn col4 = new TableColumn();
	col4.setIdentifier("PARTSHIP");
	col4.setHeaderValue("Shipping Date");
	table.addColumn(col4);
	
	// create table column 5
	TableColumn col5 = new TableColumn();
	col5.setIdentifier("MANUFACT");
	col5.setHeaderValue("Manufacturer");
	table.addColumn(col5);
	
	// create table column 6
	TableColumn col6 = new TableColumn();
	col6.setIdentifier("VENDORID");
	col6.setHeaderValue("Vendor ID");
	table.addColumn(col6);
	
	scrollPane.setColumnHeaderView(table.getTableHeader());
	scrollPane.setVerticalScrollBarPolicy(JScrollPane.VERTICAL_SCROLLBAR_ALWAYS);
	scrollPane.setHorizontalScrollBarPolicy(JScrollPane.HORIZONTAL_SCROLLBAR_ALWAYS);
	scrollPane.setBounds(21, 22, 652, 282);
	scrollPane.setViewportView(table);
	
	contentPane.add(scrollPane);
	
	bReadAll = new JButton("Read All");
	bReadAll.setBounds(175, 332, 85, 25);
	contentPane.add(bReadAll);
	
	bCloseFile = new JButton("Close File");
	bCloseFile.setBounds(435, 332, 89, 25);
	contentPane.add(bCloseFile);
	
	bReadAll.addActionListener(this);
	bCloseFile.addActionListener(this);
	this.addWindowListener(this);
	
	// set scrollPane as the display container,
	// such that the records retrieved from the database are
	// displayed in the scrollPane, which contains JFormattedTable.
	getListManager1().setDisplayContainer(scrollPane);

	return contentPane;
}

private AS400 getAs400()
{
	if (as400 == null) as400 = new com.ibm.as400.access.AS400();
	return as400;
}
	
/**
 * Return the ListManager1 property value.
 * @return com.ibm.etools.iseries.ui.ListManager
 */
private com.ibm.etools.iseries.ui.ListManager getListManager1() 
{
	if (listManager1 == null) 
	{
		try 
		{
			listManager1 = new ListManager();
			
			// Associate a database with listManager by setting RecordIOManager.
			// Database "PRODDTL" in library "ADTSLAB", record format "PRODUCT" is set.
			// The database will be keyed access, and is opened as read and write.
			
			listManager1.setRecordIOManager(
					new RecordIOManager("PRODDTL","ADTSLAB"));
					
			listManager1.setSystem(getAs400());

		} 
		catch (java.lang.Throwable ex) 
		{
			ex.printStackTrace();
		}
	}
	return listManager1;
}
/**
 * Return the ListManager2 property value.
 * @return com.ibm.etools.iseries.ui.ListManager
 */
private com.ibm.etools.iseries.ui.ListManager getListManager2() 
{
	if (listManager2 == null) 
	{
		try 
		{
			listManager2 = new ListManager();
			

			// Associate a database with listManager by setting RecordIOManager.
			// Database "MODEL" in library "ADTSLAB", record format "PRODUCT" is set.
			// The database will be keyed access, and is opened as read and write.
			
			listManager2.setRecordIOManager(
					new RecordIOManager("MODEL","ADTSLAB"));
					
			listManager2.setSystem(getAs400());

		} 
		catch (java.lang.Throwable ex) 
		{
			ex.printStackTrace();
		}
	}
	return listManager2;
}

/**
 * main entrypoint - starts the part when it is run as an application
 * @param args java.lang.String[]
 */
public static void main(java.lang.String[] args) {
	try {
		ListManagerJoinDatabases aListManagerJoinDatabases;
		aListManagerJoinDatabases = new ListManagerJoinDatabases();
		aListManagerJoinDatabases.addWindowListener(new java.awt.event.WindowAdapter() {
			public void windowClosing(java.awt.event.WindowEvent e) {
				System.exit(0);
			};
		});
		aListManagerJoinDatabases.show();
		aListManagerJoinDatabases.setVisible(true);
	} catch (Throwable exception) {
		System.err.println("Exception occurred in main()");
		exception.printStackTrace(System.out);
	}
}
}
