package com.ibm.etools.iseries.examples.dfu.ListManagerSample;


// Licensed Material - Property of IBM
// (C) Copyright IBM Corp. 2002 - All Rights Reserved
//
// DISCLAIMER:
// The following [enclosed] code is sample code created by IBM
// Corporation.  This sample code is not part of any standard IBM product
// and is provided to you solely for the purpose of assisting you in the
// development of your applications.  The code is provided 'AS IS',
// without warranty of any kind.  IBM shall not be liable for any damages
// arising out of your use of the sample code, even if IBM has been
// advised of the possibility of such damages.

/**
 * This sample will refer to iSeries files in ADTSLAB library. To be able
 * to run the sample, you have to first restore ADTSLAB savf from library
 * QPDA in WebSphere Development Studio product on V5R1M0 or later releases.
 * For early releases, you need to apply the appropriate PTF listed below
 * for the Application Development ToolSet/400 product:
 *
 * iSeries Release		LPP Number		PTF Number
 * V4R2M0				5769PW100		SF63545
 * V4R4M0				5769PW100		SF63703
 *
 *
 * This sample program demonstrates the use of ListManager,
 * RecordIOManager and JFormattedTable beans without using the VCE.
 *
 * This sample creates a GUI with a table and a button.
 * The form is associate to a specified database, such that 
 * when method readAllRecords() is invoked by pressing the button,
 * all records from the database are retrieved and populated in
 * the table. 
 *
 * Functions that you can perform with the example:
 * 1) By clicking button "readAllRecords", it will invoke method
 * readAllRecords() and all the records from the database are displayed.
 * 
 */


import javax.swing.*;
import java.awt.*;
import java.awt.event.*;
import com.ibm.etools.iseries.ui.ListManager;
import com.ibm.etools.iseries.ui.RecordIOManager;
import com.ibm.etools.iseries.ui.JFormattedTable;


public class ListManagerSample extends JFrame implements ActionListener
{
	private JFormattedTable itemTable;
	private JScrollPane scrollPane;
	
	public javax.swing.JButton buttonReadAll;
	public ListManager listManager;


/**
 * Constructor
 */
public ListManagerSample() {
	
	super("ListManagerJFormattedTableSample");
	initialize();
	
		
}
public void actionPerformed(ActionEvent e) 
{
	Object obj = e.getSource();
	
	// When buttonReadAll is pressed, listManager will perform
	// readAllRecords, which will read all the records from the 
	// database specified in RecordIOManager
	if (obj == buttonReadAll)
	{
		try 
		{
		  listManager.readAllRecords();
		}
		catch (Exception exp)
		{
			exp.printStackTrace();
		}
	     
	}
}

private void initialize() 
{
	try
	{
		// add JFormattedTable to the content pane of this JFrame
		itemTable = new JFormattedTable();
		scrollPane = new JScrollPane(itemTable);   
	
		// add the scroll pane to this window
		getContentPane().add(scrollPane, BorderLayout.CENTER);

		// add a button to the content pane
		buttonReadAll = new JButton("readAllRecords");
		buttonReadAll.addActionListener(this);
		getContentPane().add(buttonReadAll, BorderLayout.SOUTH);
			
		// instantiate list manager
		listManager = new ListManager();

		// select the columns that you are interested in from the database
		java.util.ArrayList columns = new java.util.ArrayList();
		columns.add("PARTNO");
		columns.add("MODEL");
		columns.add("PARTPRI");
		columns.add("PARTMSR");
		columns.add("PARTDIS");
		columns.add("PARTSHIP");


		// Associate a database with listManager by setting RecordIOManager.
		// Database "PRODUCT" in library "ADTSLAB", record format "PRODUC1" is set.
		// The database will be keyed access, and is opened as read and write.
		listManager.setRecordIOManager(new RecordIOManager(
			"","","","PRODUCT","ADTSLAB",
			RecordIOManager.FILEACCESS_KEYED,
			RecordIOManager.OPENTYPE_READ_WRITE, 10,
			RecordIOManager.COMMITLOCKLEVEL_NONE, "","",
			"PRODUC1", columns));

		// set scrollPane as the display container of listManager,
		// such that the records retrieved from the database are
		// displayed in the scrollPane, which contains JFormattedTable.
		listManager.setDisplayContainer(scrollPane);
	}
	catch (Throwable e)
	{
		e.printStackTrace();
	}

}


public static void main(java.lang.String[] args) 
{
	
	ListManagerSample sampleFrame = new ListManagerSample();
	sampleFrame.addWindowListener(new WindowAdapter()
	{
		public void windowClosing(WindowEvent event)
		{
			System.exit(0);
		}
	});
	sampleFrame.pack();
	sampleFrame.setVisible(true);
	
	
}
}
