package com.ibm.etools.iseries.examples.dfu.ListManagerSample3;


// Licensed Material - Property of IBM
// (C) Copyright IBM Corp. 2002 - All Rights Reserved
//
// DISCLAIMER:
// The following [enclosed] code is sample code created by IBM
// Corporation.  This sample code is not part of any standard IBM product
// and is provided to you solely for the purpose of assisting you in the
// development of your applications.  The code is provided 'AS IS',
// without warranty of any kind.  IBM shall not be liable for any damages
// arising out of your use of the sample code, even if IBM has been
// advised of the possibility of such damages.

/**
 * This sample will refer to iSeries files in ADTSLAB library. To be able
 * to run the sample, you have to first restore ADTSLAB savf from library
 * QPDA in WebSphere Development Studio product on V5R1M0 or later releases.
 * For early releases, you need to apply the appropriate PTF listed below
 * for the Application Development ToolSet/400 product:
 *
 * iSeries Release		LPP Number		PTF Number
 * V4R2M0				5769PW100		SF63545
 * V4R4M0				5769PW100		SF63703
 *
 *
 * This sample program demonstrates how you can use ListManager to
 * retrieve data from a database and populate the data in a JList
 * and JComboBox.
 *
 * Functions that you can perform with the example:
 * 1) By clicking button "Read All", a sign on dialog will pop
 * up for you to log on to your server, then it will retrieve
 * all the records from the database "PRODDTL" in library "ADTSLAB".
 * Data from field PARTNO will be displayed in the JComboBox, and 
 * data from field PARTD will be displayed in JList.
 * 
 * 2) Select an item in JComboBox, will highlight the corresponding 
 * description in JList.
 * 
 * 3) By clicking button "Close File" will close the database.
 * 
 */ 

import javax.swing.*;
import com.ibm.etools.iseries.ui.*;


public class ListManagerSample3 extends JFrame implements 
			java.awt.event.ActionListener, java.awt.event.ItemListener 
{
	private JButton bReadAll = null;
	private JButton bCloseFile = null;
	private JScrollPane scrollPane = null;
	private com.ibm.etools.iseries.ui.ListManager listManager = null;
	private JList lPartd = null;
	private JComboBox cbPartno = null;



/**
 * Constructor
 */
public ListManagerSample3() 
{
	super("ListManagerSample3");
	setDefaultCloseOperation(WindowConstants.DISPOSE_ON_CLOSE);
	setSize(491, 400);
	setContentPane(getJFrameContentPane());

}
public void actionPerformed(java.awt.event.ActionEvent e) 
{
	Object obj = e.getSource();
	
	try
	{
		if (obj == bReadAll) 
			getListManager().readAllRecords();
		if (obj == bCloseFile) 
			getListManager().closeFile();
	}
	catch (Exception ex)
	{
		ex.printStackTrace();
	}
}
public void itemStateChanged(java.awt.event.ItemEvent e) 
{
	if (e.getSource() == cbPartno) 
		lPartd.setSelectedIndex(cbPartno.getSelectedIndex());
}
/**
 * Return the JFrameContentPane property value.
 * @return JPanel
 */
private JPanel getJFrameContentPane()
{
	JPanel contentPane = new JPanel();
	contentPane.setLayout(null);

	cbPartno = new JComboBox();
	cbPartno.setName("partno");
	cbPartno.setBounds(34, 50, 147, 27);
	contentPane.add(cbPartno);
	
	lPartd = new JList();
	lPartd.setName("partd");
	lPartd.setBounds(0, 0, 160, 120);

	scrollPane = new JScrollPane();
	scrollPane.setName("JScrollPane1");
	scrollPane.setBounds(260, 50, 173, 194);
	scrollPane.setViewportView(lPartd);
	contentPane.add(scrollPane);

	JLabel label1 = new JLabel("Part Number:");
	label1.setBounds(35, 26, 156, 19);
	contentPane.add(label1);
	
	JLabel label2 = new JLabel("Part Description:");
	label2.setBounds(260, 26, 156, 19);
	contentPane.add(label2);
	
	bReadAll = new JButton("Read All");
	bReadAll.setBounds(76, 288, 85, 25);
	contentPane.add(bReadAll);
	
	bCloseFile = new JButton("Close File");
	bCloseFile.setBounds(268, 288, 95, 25);
	contentPane.add(bCloseFile);
	
	getListManager().setDisplayContainer(contentPane);

	
	// add listeners to buttons and comboBox
	bReadAll.addActionListener(this);
	bCloseFile.addActionListener(this);
	cbPartno.addItemListener(this);

	return contentPane;
}
/**
 * Return the ListManager1 property value.
 * @return com.ibm.etools.iseries.ui.ListManager
 */
private com.ibm.etools.iseries.ui.ListManager getListManager() 
{
	if (listManager == null) 
	{
		// instantiate list manager
		listManager = new ListManager();

		try
		{
			// Associate a database with listManager by setting RecordIOManager.
			// Database is "PRODDTL" in library "ADTSLAB". By default,
			// the database is opened in read and write mode and accessed
			// by key.
			listManager.setRecordIOManager(new RecordIOManager("PRODDTL","ADTSLAB"));
		} 
		catch (java.lang.Throwable ex) 
		{
			ex.printStackTrace();
		}
	}
	return listManager;
}
/**
 * main entrypoint - starts the part when it is run as an application
 * @param args java.lang.String[]
 */
public static void main(java.lang.String[] args) 
{
	try {
		ListManagerSample3 aListManagerSample3;
		aListManagerSample3 = new ListManagerSample3();
		aListManagerSample3.addWindowListener(new java.awt.event.WindowAdapter() {
			public void windowClosing(java.awt.event.WindowEvent e) {
				System.exit(0);
			};
		});
		aListManagerSample3.show();
		aListManagerSample3.setVisible(true);
	} catch (Throwable exception) {
		System.err.println("Exception occurred in main()");
		exception.printStackTrace(System.out);
	}
}
}
