package com.ibm.etools.iseries.examples.jformatted.JFormattedTableSample;


// Licensed Material - Property of IBM
// (C) Copyright IBM Corp. 2000 - All Rights Reserved
//
// DISCLAIMER:
// The following [enclosed] code is sample code created by IBM
// Corporation.  This sample code is not part of any standard IBM product
// and is provided to you solely for the purpose of assisting you in the
// development of your applications.  The code is provided 'AS IS',
// without warranty of any kind.  IBM shall not be liable for any damages
// arising out of your use of the sample code, even if IBM has been
// advised of the possibility of such damages.

/**
 * This sample program demonstrates use of the following beans:
 * - JFormattedTable
 * - JFormattedTableColumn 
 * - JFormattedLabelCellRenderer
 * - JFormattedTextFieldCellEditor
 * - JFormattedComboBoxCellEditor
 *
 * Functions that you can perform with the example:
 * 1) This sample populates the table with data defined in variable items.
 * The column "ItemNo" demonstrates how to define a Label cell renderer
 * in a JFormattedTable. The cells in this column is not editable, for
 * it is using a label cell renderer.
 * 2) The column "Model" demonstrates how to define a text field 
 * as a cell editor in JFormattedTable. The editor is a JFormattedTextField,
 * which is set with editword format. If you double click on a cell in this 
 * column, you can edit the cell, and you can see the editword
 * format.
 * 3) The column "Size" demonstrates how to define a combo box as
 * a cell editor in JFormattedTable. 
 * 4) The column "Price" demonstrates how to define a text field
 * as a cell editor in JFormattedTable. The editor is a JFormattedTextField,
 * which is set with edit code format. If you double click on a cell
 * in this column, you can edit the cell, the cell only accepts numeric
 * value with length of 10, decimal places of 2. When you tab or exit
 * from the focus of the cell, the field is formatted.
 */

import javax.swing.*;
import javax.swing.table.*;
import java.awt.*;
import java.awt.event.*;
import com.ibm.etools.iseries.ui.*;


public class JFormattedTableSample extends JFrame{
	
	private DefaultTableModel itemTableModel ;
	private JFormattedTable   itemTable;
	private JFormattedTableColumn itemNoColumn;
	private JFormattedTableColumn modelColumn;
	private JFormattedTableColumn sizeColumn;
	private JFormattedTableColumn priceColumn;
	private JScrollPane scrollPane;
	
	// sizes in the combo box
	final String[] size = { "small", "medium", "big"};
		                       
	// items in the table 
	final Object[][] items = {
	                            {"00001", "2000AB1", size[0], "100"},
								{"00002", "2000AB2", size[0], "200.50"},
								{"00003", "2000AB3", size[1], "369"},
								{"00004", "2000AB4", size[2], "700"},
								{"00005", "2000AB5", size[0], "405"},
							    {"00006", "2000AB6", size[0], "110"},
								{"00007", "2000AB7", size[0], "230.49"},
								{"00008", "2000AB8", size[1], "268"},
								{"00009", "2000AB9", size[2], "732"},
								{"00010", "2000AB9", size[0], "860"},
							 };
	
	// Header of the table columns
	final String[] columnNames = {"ItemNo", "Model", "Size", "Price"};


	
/**
 * JFormattedTableSample constructor
 */
public JFormattedTableSample() {
	
	super("JFormattedTableSample");
	initialize();
	setUpTableColumns();
		
}
/**
 * initialize the objects
 */
private void initialize() {


	// create item table.
	itemTableModel = new DefaultTableModel(items, columnNames);
	itemTable = new JFormattedTable(itemTableModel);
	itemTable.setAutoResizeMode( JFormattedTable.AUTO_RESIZE_ALL_COLUMNS);
	itemTable.setPreferredScrollableViewportSize(new Dimension(300,100));
	// specify 4 rows are visible at once
	itemTable.setVisibleRowCount(4);


	
	// create the scroll pane and add the table to it.
	scrollPane = new JScrollPane(itemTable);   


	// add the scroll pane to this window
	getContentPane().add(scrollPane, BorderLayout.CENTER);
	
	// get columns
	try {
	itemNoColumn = (JFormattedTableColumn)itemTable.getColumn("ItemNo");
	} catch (Exception e){
		itemNoColumn = null;
	}
	
	try{
	modelColumn  = (JFormattedTableColumn)itemTable.getColumn("Model");
	} catch (Exception e){
		modelColumn = null;
	}


	try{
	sizeColumn   = (JFormattedTableColumn)itemTable.getColumn("Size");
	} catch (Exception e){
		sizeColumn = null;
	}


	try {
	priceColumn  = (JFormattedTableColumn)itemTable.getColumn("Price");
	} catch (Exception e){
		priceColumn = null;
	}
	
		
}
public static void main(java.lang.String[] args) {
	
	JFormattedTableSample jft = new JFormattedTableSample();
	jft.addWindowListener(new WindowAdapter(){
		public void windowClosing(WindowEvent event){
			System.exit(0);
		}
	});
	jft.pack();
	jft.setVisible(true);
	
}
/**
 * set up the itemNoColumn
 * 
 */
private void setUpItemNoColumn(JFormattedTableColumn aItemNoColumn) {
	// do nothing if the column is null 
	if (aItemNoColumn == null )
	        return;
	else {        
	// set up the field model
	Attributes dataAttr = new DataAttributes(DataAttributes.DATATYPE_CHARACTER,8);
	Formatter formatter = new EditcodeEditwordFormatter();
	AS400FieldModel fm = new AS400FieldModel(dataAttr, formatter);
	aItemNoColumn.setFieldModel(fm);
	
	// set itemNoColumn as uneditable
	aItemNoColumn.setCellEditable(false);
	};
	
	
		
}
/**
 * set up the modelColumn. 
 * 
 */
private void setUpModelColumn(JFormattedTableColumn aModelColumn) {
	// do nothing if the column is null 
	if (aModelColumn == null )
	        return;
	else {  
	// set up the field model
	
	Attributes dataAttr = new DataAttributes(DataAttributes.DATATYPE_CHARACTER,7);
	Formatter formatter = new EditcodeEditwordFormatter(dataAttr, '0', EditcodeEditwordFormatter.EDITCODEPARM_NONE, "    -  - ");
	
	AS400FieldModel fm = new AS400FieldModel(dataAttr, formatter);
	aModelColumn.setFieldModel(fm);


	// set up the editmaskAttributes used when editing
	try{
	aModelColumn.setEditmaskAttributes(new EditmaskAttributes("    -  - ","    &  & "));
	} catch (Exception e)
	{
	};
	
	// set up the cellrenderer as a customized JFormattedLabelCellRenderer: align to CENTER when renderring
	
	JFormattedLabelCellRenderer aCellRenderer = (JFormattedLabelCellRenderer)aModelColumn.getCellRenderer();
	aCellRenderer.setHorizontalAlignment(javax.swing.JLabel.CENTER);
	
	// set up the celleditor as a customized JFormattedTextFieldCellEditor: align to LEFT when editing
	
	JFormattedTextFieldCellEditor aCellEditor = (JFormattedTextFieldCellEditor)aModelColumn.getCellEditor();
	aCellEditor.setHorizontalAlignment(javax.swing.JTextField.LEFT);
	
	}
	
		
}
/**
 * set up the priceColumn
 * 
 */
private void setUpPriceColumn(JFormattedTableColumn aPriceColumn) {
	// do nothing if the column is null 
	if (aPriceColumn == null )
	        return;
	else {  
	// set up the field model
	
	Attributes dataAttr = new DataAttributes(DataAttributes.DATATYPE_NUMERIC,8,2,'.');
	Formatter formatter = new EditcodeEditwordFormatter();
	AS400FieldModel fm = new AS400FieldModel(dataAttr, formatter);
	aPriceColumn.setFieldModel(fm);
	
	}	
	
	
		
}
/**
 * set up the sizeColumn
 * 
 */
private void setUpSizeColumn(JFormattedTableColumn aSizeColumn) {
	// do nothing if the column is null 
	if (aSizeColumn == null )
	        return;
	else {  
	// set up the field model
	
	Attributes dataAttr = new DataAttributes(DataAttributes.DATATYPE_CHARACTER,10);
	Formatter formatter = new EditcodeEditwordFormatter();
	AS400FieldModel fm = new AS400FieldModel(dataAttr, formatter);
	aSizeColumn.setFieldModel(fm);
	
		
	// set up the celleditor as a customized JFormattedComboBoxCellEditor
	JFormattedComboBoxCellEditor aCellEditor = new JFormattedComboBoxCellEditor(size);
	aSizeColumn.setCellEditor(aCellEditor);


	// set up the cellrenderer's ToolTipText
	JFormattedLabelCellRenderer aCellRenderer = (JFormattedLabelCellRenderer)aSizeColumn.getCellRenderer();
	aCellRenderer.setToolTipText("Click to bring up the list");
	
	}
		
}
/**
 * set up all table columns. You do not need to set up a column if the default properties of JFormattedTableColumn are OK with you. 
 */
private void setUpTableColumns() {
	
	setUpItemNoColumn(itemNoColumn);
	setUpModelColumn(modelColumn);
	setUpSizeColumn(sizeColumn);
	setUpPriceColumn(priceColumn);
	
}
}
