package com.ibm.etools.iseries.examples.toolbox;


/////////////////////////////////////////////////////////////////////////
//
// VIFSDirectory example.  This program presents a tree view of
// some directories in the integrated file system.
//
// Command syntax:
//    VIFSDirectoryExample system
//
/////////////////////////////////////////////////////////////////////////
//
// This source is an example of AS/400 Toolbox for Java "VIFSDirectory".
// IBM grants you a nonexclusive license to use this as an example
// from which you can generate similar function tailored to
// your own specific needs.
//
// This sample code is provided by IBM for illustrative purposes
// only. These examples have not been thoroughly tested under all
// conditions. IBM, therefore, cannot guarantee or imply
// reliability, serviceability, or function of these programs.
//
// All programs contained herein are provided to you "AS IS"
// without any warranties of any kind.  The implied warranties of
// merchantablility and fitness for a particular purpose are
// expressly disclaimed.
//
// AS/400 Toolbox for Java
// (C) Copyright IBM Corp. 1997, 1998
// All rights reserved.
// US Government Users Restricted Rights -
// Use, duplication, or disclosure restricted
// by GSA ADP Schedule Contract with IBM Corp.
//
/////////////////////////////////////////////////////////////////////////


import com.ibm.as400.access.*;
import com.ibm.as400.vaccess.*;
import javax.swing.*;
import java.awt.*;
import java.awt.event.*;


public class VIFSDirectoryExample
{



	public static void main (String[] args)
	{
		// If a system was not specified, then display help text and
		// exit.
		if (args.length != 1)
		{
			System.out.println("Usage:  VIFSDirectoryExample system");
			return;
		}


		try
		{
			// Create an AS400 object.  The system name was passed
			// as the first command line argument.
			AS400 system = new AS400 (args[0]);


			// Create a VIFSDirectory object which represents the root
			// of the directory tree that we are going to show.
			VIFSDirectory directory = new VIFSDirectory (system, "/QIBM/ProdData");


			// Create a frame.
			JFrame f = new JFrame ("VIFSDirectory example");


			// Create an error dialog adapter.  This will display
			// any errors to the user.
			ErrorDialogAdapter errorHandler = new ErrorDialogAdapter (f);


			// Create a tree pane to present the directories hierarchically.
			// Load the information from the system.
			AS400TreePane treePane = new AS400TreePane (directory);
			treePane.addErrorListener (errorHandler);
			treePane.load ();


			// When the frame closes, exit.
			f.addWindowListener (new WindowAdapter () {
				public void windowClosing (WindowEvent event)
				{
					System.exit (0);
				}
			});


			// Layout the frame with the tree pane.
			f.getContentPane ().setLayout (new BorderLayout ());
			f.getContentPane ().add ("Center", treePane);
			f.pack ();
			f.show ();
		}
		catch (Exception e)
		{
		   System.out.println ("Error: " + e.getMessage ());
		   System.exit (0);
		}
	}
}
