package com.ibm.etools.iseries.examples.toolbox;


//////////////////////////////////////////////////////////////////////////////////
//
// IFSListFile example.  This program uses the integrated file system classes
// to list the contents of a directory on the AS/400.
//
// Command syntax:
//    IFSList system directory
//
// For example,
//    IFSList MySystem /path1
//
//
//////////////////////////////////////////////////////////////////////////////////
//
// This source is an example of AS/400 Toolbox for Java "IFSFile".
// IBM grants you a nonexclusive license to use this as an example
// from which you can generate similar function tailored to
// your own specific needs.
//
// This sample code is provided by IBM for illustrative purposes
// only. These examples have not been thoroughly tested under all
// conditions. IBM, therefore, cannot guarantee or imply
// reliability, serviceability, or function of these programs.
//
// All programs contained herein are provided to you "AS IS"
// without any warranties of any kind.  The implied warranties of
// merchantablility and fitness for a particular purpose are
// expressly disclaimed.
//
// AS/400 Toolbox for Java
// (C) Copyright IBM Corp. 1997
// All rights reserved.
// US Government Users Restricted Rights -
// Use, duplication, or disclosure restricted
// by GSA ADP Schedule Contract with IBM Corp.
//
//////////////////////////////////////////////////////////////////////////////////





import java.io.*;
import java.util.*;
import com.ibm.as400.access.*;


////////////////////////////////////////////////////////////////////////////
//
// The directory filter class prints information from the file object.
//
// Another way to use the filter is to simply return true or false
// based on information in the file object.  This lets the mainline
// function decide what to do with the list of files that meet the
// search criteria.
//
////////////////////////////////////////////////////////////////////////////





class directoryFilter implements IFSFileFilter
{
   public boolean accept(IFSFile file)
   {
	  try
	  {
		 // Print the name of the current file


		 System.out.print(file.getName());





		 // Pad the output so the columns line up


		 for (int i = file.getName().length(); i < 18; i++)
			System.out.print(" ");





		 // Print the date the file was last changed.


		 long changeDate = file.lastModified();
		 Date d = new Date(changeDate);
		 System.out.print(d);
		 System.out.print("  ");





		 // Print if the entry is a file or directory


		 System.out.print("   ");


		 if (file.isDirectory())
			System.out.println("<DIR>");
		 else
			System.out.println(file.length());





		 // Keep this entry.  Returning true tells the IFSList object
		 // to return this file in the list of entries returned to the
		 // .list() method.


		 return true;
	  }


	  catch (Exception e)
	  {
		 return false;
	  }
   }   
}
